@@ -56,7 +56,7 @@ def has_foreign_lemma(word):
 def load_exceptions():
     cdir = pathlib.Path(__file__).parent.absolute()
     exceptions = {}
-    for line in open(cdir / 'exceptions.tsv'):
+    for line in open(cdir / 'exceptions.tsv', encoding='utf-8'):
         line = line.strip()
         # allow comments and blanks
         if line[0] == '#' or not line: continue
@@ -114,6 +114,8 @@ class Cutlet:
 
         # convert all full-width alphanum to half-width, since it can go out as-is
         text = mojimoji.zen_to_han(text, kana=False)
+        # replace half-width katakana with full-width
+        text = mojimoji.han_to_zen(text, digit=False, ascii=False)
 
         words = self.tagger(text)
 
